SettingsSpec

Enum SettingsSpec 

pub enum SettingsSpec {
    Real {
        name: String,
        description: String,
        minimum: f64,
        maximum: f64,
        default: f64,
    },
    Integer {
        name: String,
        description: String,
        minimum: i64,
        maximum: i64,
        default: i64,
    },
    Boolean {
        name: String,
        description: String,
        default: bool,
    },
    Enumeration {
        name: String,
        description: String,
        values: Vec<String>,
        default: String,
    },
    String {
        name: String,
        description: String,
        default: String,
    },
}
Description of an environmental parameter.

Variants



Real

Fields

name: String
description: String
minimum: f64

Lower bound on the range of allowable values, inclusive.

maximum: f64

Upper bound on the range of allowable values, inclusive.

default: f64


Integer

Fields

name: String
description: String
minimum: i64

Lower bound on the range of allowable values, inclusive.

maximum: i64

Upper bound on the range of allowable values, inclusive.

default: i64


Boolean

Fields

name: String
description: String
default: bool


Enumeration

Fields

name: String
description: String
values: Vec<String>

Names of all of the variants of the enumeration.

default: String


String

Fields

name: String
description: String
default: String

Implementations

Source

impl SettingsSpec

pub fn name(&self) -> &str

Name of this settings menu item, must be unique within the environment.

pub fn description(&self) -> &str

User facing documentation message.

pub fn type(&self) -> &str

Data type.

pub fn default(&self) -> String