Individual

Struct Individual 

pub struct Individual {
Show 17 fields pub name: String, pub ascension: Option<u64>, pub environment: String, pub population: String, pub species: String, pub controller: Vec<String>, pub genome: OnceLock<Arc<[u8]>>, pub telemetry: HashMap<String, String>, pub epigenome: HashMap<String, String>, pub score: Option<String>, pub generation: u64, pub parents: Vec<String>, pub children: Vec<String>, pub birth_date: String, pub death_date: String, pub extra: HashMap<String, Value>, pub path: Option<PathBuf>,
}
Container for a distinct life-form and all of its associated data.

Fields

name: String

Name or UUID of this individual.

ascension: Option<u64>

Number of individuals who died before this one, or None if this individual has not yet died.

environment: String

Name of the environment that this individual lives in.

population: String

Name of the population that this individual belongs to.

species: String

Name or UUID of this individual’s species. Mating may be restricted to individuals of the same species.

controller: Vec<String>

Command line invocation of the controller program.

genome: OnceLock<Arc<[u8]>>

Genetic parameters for this individual.

telemetry: HashMap<String, String>

The environmental info dictionary. The environment updates this information.

epigenome: HashMap<String, String>

The epigenetic info dictionary. The controller updates this information.

score: Option<String>

Reproductive fitness of this individual, as assessed by the environment.

generation: u64

Number of cohorts that passed before this individual was born.

parents: Vec<String>

The names of this individual’s parents.

children: Vec<String>

The names of this individual’s children.

birth_date: String

Time of birth, as a UTC timestamp, or an empty string if this individual has not yet been born.

death_date: String

Time of death, as a UTC timestamp, or an empty string if this individual has not yet died.

extra: HashMap<String, Value>

Custom / unofficial fields that are saved with the individual.

path: Option<PathBuf>

The file path this individual was loaded from or saved to, or None if this individual has not touched the file system.

Implementations

Source

impl Individual

pub fn new( environment: &str, population: &str, controller: &[&str], genome: Box<[u8]>, ) -> Individual

Create a new individual.

pub fn genome(&self) -> Arc<[u8]>

Get the genetic parameters for this individual. This loads the genome from file if necessary.

pub fn asex(&mut self, child_genome: &[u8]) -> Individual

Asexually reproduce an individual.

pub fn sex(&mut self, other: &mut Individual, child_genome: &[u8]) -> Individual

Sexually reproduce two individuals.

pub fn save(&mut self, path: impl AsRef<Path>) -> Result<&Path, Error>

Save an individual to a file.

Argument path is the directory to save in. Optional, use empty string for temporary file. The filename will be the individual’s name with the “.indiv” file extension.

Returns the file path of the saved individual.

pub fn load(path: impl AsRef<Path>) -> Result<Individual, Error>

Load a previously saved individual.

pub fn load_dir(path: impl AsRef<Path>) -> Result<Vec<Individual>, Error>

Get all individuals saved in a directory.

pub fn delete(self) -> Result<(), Error>

Remove this individual and its associated save file.

pub fn drop(this: Arc<Mutex<Self>>) -> Result<(), Error>

Delete the individual if this is the last reference to it.